@@ -4,6 +4,15 @@ function (x, ...)
   cat ("\n Call: \n")
   print (x$call)
   
+  cat ("# of cases=", x$cases, "\n")
+  cat ("# of classes=", x$classes, "\n")
+  cat ("# of features=", x$features, "\n")
+  
+  cat ("\n Lambdas used:", x$lambda, "\n")
+  
+  cat ("\n Estimated Coefficients: \n")
+  print (x$coefficient)  
+  
   cat ("\n Predicted classification: \n")
   print (x$predicted)
   
