@@ -5,14 +5,6 @@ function (object, ...)
   print (object$call)
   cat ("\n")
   
-  cat ("\n Feature Matrix \n")
-  print (object$feature)
-  cat ("\n")
-  
-  cat ("\n Standardized Feature Matrix: \n")
-  print (object$stand.feature)
-  cat ("\n")
-  
   cat ("# of cases=", object$cases, "\n")
   cat ("# of classes=", object$classes, "\n")
   cat ("# of features=", object$features, "\n")
